/*
 *  EPSG/POSC Datum database -- GeoTIFF Rev. 0.2
 */
 
/* C database for Geotiff include files.   */
/* the macro ValuePair() must be defined   */
/* by the enclosing include file           */

#ifdef INCLUDE_OLD_CODES
#include old_datum.inc
#endif /* OLD Codes */

/* New datums */
ValuePair(Datum_Dealul_Piscului_1970,6317)

/* Datums for which only the ellipsoid is known */
ValuePair(DatumE_Airy1830,	6001)
ValuePair(DatumE_AiryModified1849,	6002)
ValuePair(DatumE_AustralianNationalSpheroid,	6003)
ValuePair(DatumE_Bessel1841,	6004)
ValuePair(DatumE_BesselModified,	6005)
ValuePair(DatumE_BesselNamibia,	6006)
ValuePair(DatumE_Clarke1858,	6007)
ValuePair(DatumE_Clarke1866,	6008)
ValuePair(DatumE_Clarke1866Michigan,	6009)
ValuePair(DatumE_Clarke1880_Benoit,	6010)
ValuePair(DatumE_Clarke1880_IGN,	6011)
ValuePair(DatumE_Clarke1880_RGS,	6012)
ValuePair(DatumE_Clarke1880_Arc,	6013)
ValuePair(DatumE_Clarke1880_SGA1922,	6014)
ValuePair(DatumE_Everest1830_1937Adjustment,	6015)
ValuePair(DatumE_Everest1830_1967Definition,	6016)
ValuePair(DatumE_Everest1830_1975Definition,	6017)
ValuePair(DatumE_Everest1830Modified,	6018)
ValuePair(DatumE_GRS1980,	6019)
ValuePair(DatumE_Helmert1906,	6020)
ValuePair(DatumE_IndonesianNationalSpheroid,	6021)
ValuePair(DatumE_International1924,	6022)
ValuePair(DatumE_International1967,	6023)
ValuePair(DatumE_Krassowsky1960,	6024)
ValuePair(DatumE_NWL9D,	6025)
ValuePair(DatumE_NWL10D,	6026)
ValuePair(DatumE_Plessis1817,	6027)
ValuePair(DatumE_Struve1860,	6028)
ValuePair(DatumE_WarOffice,	6029)
ValuePair(DatumE_WGS84,	6030)
ValuePair(DatumE_GEM10C,	6031)
ValuePair(DatumE_OSU86F,	6032)
ValuePair(DatumE_OSU91A,	6033)
ValuePair(DatumE_Clarke1880,	6034)
ValuePair(DatumE_Sphere,	6035)

/* standard datums */
ValuePair(Datum_Adindan,	6201)
ValuePair(Datum_Australian_Geodetic_Datum_1966,	6202)
ValuePair(Datum_Australian_Geodetic_Datum_1984,	6203)
ValuePair(Datum_Ain_el_Abd_1970,	6204)
ValuePair(Datum_Afgooye,	6205)
ValuePair(Datum_Agadez,	6206)
ValuePair(Datum_Lisbon,	6207)
ValuePair(Datum_Aratu,	6208)
ValuePair(Datum_Arc_1950,	6209)
ValuePair(Datum_Arc_1960,	6210)
ValuePair(Datum_Batavia,	6211)
ValuePair(Datum_Barbados,	6212)
ValuePair(Datum_Beduaram,	6213)
ValuePair(Datum_Beijing_1954,	6214)
ValuePair(Datum_Reseau_National_Belge_1950,	6215)
ValuePair(Datum_Bermuda_1957,	6216)
ValuePair(Datum_Bern_1898,	6217)
ValuePair(Datum_Bogota,	6218)
ValuePair(Datum_Bukit_Rimpah,	6219)
ValuePair(Datum_Camacupa,	6220)
ValuePair(Datum_Campo_Inchauspe,	6221)
ValuePair(Datum_Cape,	6222)
ValuePair(Datum_Carthage,	6223)
ValuePair(Datum_Chua,	6224)
ValuePair(Datum_Corrego_Alegre,	6225)
ValuePair(Datum_Cote_d_Ivoire,	6226)
ValuePair(Datum_Deir_ez_Zor,	6227)
ValuePair(Datum_Douala,	6228)
ValuePair(Datum_Egypt_1907,	6229)
ValuePair(Datum_European_Datum_1950,	6230)
ValuePair(Datum_European_Datum_1987,	6231)
ValuePair(Datum_Fahud,	6232)
ValuePair(Datum_Gandajika_1970,	6233)
ValuePair(Datum_Garoua,	6234)
ValuePair(Datum_Guyane_Francaise,	6235)
ValuePair(Datum_Hu_Tzu_Shan,	6236)
ValuePair(Datum_Hungarian_Datum_1972,	6237)
ValuePair(Datum_Indonesian_Datum_1974,	6238)
ValuePair(Datum_Indian_1954,	6239)
ValuePair(Datum_Indian_1975,	6240)
ValuePair(Datum_Jamaica_1875,	6241)
ValuePair(Datum_Jamaica_1969,	6242)
ValuePair(Datum_Kalianpur,	6243)
ValuePair(Datum_Kandawala,	6244)
ValuePair(Datum_Kertau,	6245)
ValuePair(Datum_Kuwait_Oil_Company,	6246)
ValuePair(Datum_La_Canoa,	6247)
ValuePair(Datum_Provisional_S_American_Datum_1956,	6248)
ValuePair(Datum_Lake,	6249)
ValuePair(Datum_Leigon,	6250)
ValuePair(Datum_Liberia_1964,	6251)
ValuePair(Datum_Lome,	6252)
ValuePair(Datum_Luzon_1911,	6253)
ValuePair(Datum_Hito_XVIII_1963,	6254)
ValuePair(Datum_Herat_North,	6255)
ValuePair(Datum_Mahe_1971,	6256)
ValuePair(Datum_Makassar,	6257)
ValuePair(Datum_European_Reference_System_1989,	6258)
ValuePair(Datum_Malongo_1987,	6259)
ValuePair(Datum_Manoca,	6260)
ValuePair(Datum_Merchich,	6261)
ValuePair(Datum_Massawa,	6262)
ValuePair(Datum_Minna,	6263)
ValuePair(Datum_Mhast,	6264)
ValuePair(Datum_Monte_Mario,	6265)
ValuePair(Datum_M_poraloko,	6266)
ValuePair(Datum_North_American_Datum_1927,	6267)
ValuePair(Datum_NAD_Michigan,	6268)
ValuePair(Datum_North_American_Datum_1983,	6269)
ValuePair(Datum_Nahrwan_1967,	6270)
ValuePair(Datum_Naparima_1972,	6271)
ValuePair(Datum_New_Zealand_Geodetic_Datum_1949,	6272)
ValuePair(Datum_NGO_1948,	6273)
ValuePair(Datum_Datum_73,	6274)
ValuePair(Datum_Nouvelle_Triangulation_Francaise,	6275)
ValuePair(Datum_NSWC_9Z_2,	6276)
ValuePair(Datum_OSGB_1936,	6277)
ValuePair(Datum_OSGB_1970_SN,	6278)
ValuePair(Datum_OS_SN_1980,	6279)
ValuePair(Datum_Padang_1884,	6280)
ValuePair(Datum_Palestine_1923,	6281)
ValuePair(Datum_Pointe_Noire,	6282)
ValuePair(Datum_Geocentric_Datum_of_Australia_1994,	6283)
ValuePair(Datum_Pulkovo_1942,	6284)
ValuePair(Datum_Qatar,	6285)
ValuePair(Datum_Qatar_1948,	6286)
ValuePair(Datum_Qornoq,	6287)
ValuePair(Datum_Loma_Quintana,	6288)
ValuePair(Datum_Amersfoort,	6289)
ValuePair(Datum_RT38,	6290)
ValuePair(Datum_South_American_Datum_1969,	6291)
ValuePair(Datum_Sapper_Hill_1943,	6292)
ValuePair(Datum_Schwarzeck,	6293)
ValuePair(Datum_Segora,	6294)
ValuePair(Datum_Serindung,	6295)
ValuePair(Datum_Sudan,	6296)
ValuePair(Datum_Tananarive_1925,	6297)
ValuePair(Datum_Timbalai_1948,	6298)
ValuePair(Datum_TM65,	6299)
ValuePair(Datum_TM75,	6300)
ValuePair(Datum_Tokyo,	6301)
ValuePair(Datum_Trinidad_1903,	6302)
ValuePair(Datum_Trucial_Coast_1948,	6303)
ValuePair(Datum_Voirol_1875,	6304)
ValuePair(Datum_Voirol_Unifie_1960,	6305)
ValuePair(Datum_Bern_1938,	6306)
ValuePair(Datum_Nord_Sahara_1959,	6307)
ValuePair(Datum_Stockholm_1938,	6308)
ValuePair(Datum_Yacare,	6309)
ValuePair(Datum_Yoff,	6310)
ValuePair(Datum_Zanderij,	6311)
ValuePair(Datum_Militar_Geographische_Institut,	6312)
ValuePair(Datum_Reseau_National_Belge_1972,	6313)
ValuePair(Datum_Deutsche_Hauptdreiecksnetz,	6314)
ValuePair(Datum_Conakry_1905,	6315)
ValuePair(Datum_WGS72,	6322)
ValuePair(Datum_WGS72_Transit_Broadcast_Ephemeris,	6324)
ValuePair(Datum_WGS84,	6326)
ValuePair(Datum_Ancienne_Triangulation_Francaise,	6901)
ValuePair(Datum_Nord_de_Guerre,	6902)
/* end of list */
